| Title: | Access TASS 6502 Assembler |
|---|---|
| Description: | A simple wrapper for the TASS 6502 assembler. |
| Authors: | mikefc |
| Maintainer: | mikefc <[email protected]> |
| License: | file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-26 09:56:30 UTC |
| Source: | https://github.com/coolbutuseless/c64tass |
Class wrapping the 64TASS assembler for easier testing of the R64 assembler
Class wrapping the 64TASS assembler for easier testing of the R64 assembler
Set 'option(TASS_BIN=...)' and 'option(X64_BIN=...)' to set the assembler and emulator executable locations, or pass in as arguments 'TASS$new(tass_bin=..., x64_bin=...)'
asmthe assembly code (as text)
tass_binlocation of TASS executable
prgc64 PRG file with compiled 6502 machine code
debugtext output during compilation Initialise TASS
new()
TASS$new(
asm = NULL,
tass_bin = getOption("TASS_BIN", "/opt/homebrew/bin/64tass")
)asmthe assembly code (as text)
tass_binlocation of TASS executable Compile asm with 64TASS
Note: Full TASS debugging output from the compilation step is kept
in the variable debug. Use tass$get_debug() to access
compile()
TASS$compile(verbosity = 1)
verbosityverboseness when compiling. 0 = no output, 1 = messages from TASS compilation, 2 = all output from TASS
get_asm()
Get the ASM text
TASS$get_asm()
get_prg()
Get the compiled code as a raw vector
TASS$get_prg()
get_debug()
Get the TASS debugging output from compilation
TASS$get_debug()
clone()
The objects of this class are cloneable with this method.
TASS$clone(deep = FALSE)
deepWhether to make a deep clone.
## Not run: tass <- TASS$new("./asm/border.asm", tass_bin = "~/bin/64tass", x64_bin = "~/bin/x64") tass$dump_asm() tass$compile() tass$get_prg() tass$get_asm() tass$compile_and_run() ## End(Not run)## Not run: tass <- TASS$new("./asm/border.asm", tass_bin = "~/bin/64tass", x64_bin = "~/bin/x64") tass$dump_asm() tass$compile() tass$get_prg() tass$get_asm() tass$compile_and_run() ## End(Not run)